pub enum Language {
Python,
Node,
Rust,
Dart,
CSharp,
Java,
}Expand description
Supported programming languages and their corresponding package manager ecosystems.
Each variant represents a language that changepacks can manage versions for.
Variants
Python
Python projects using pyproject.toml (pip, uv)
Node
Node.js projects using package.json (npm, pnpm, yarn, bun)
Rust
Rust projects using Cargo.toml (cargo)
Dart
Dart projects using pubspec.yaml (pub)
CSharp
C# projects using .csproj (NuGet, dotnet)
Java
Java projects using build.gradle or build.gradle.kts (Gradle)
Implementations